@@ -6,6 +6,7 @@ import json
 import os
 import sys
 import textwrap
+from importlib import import_module  # buffalo buffalo
 
 from .util import six
 
@@ -39,6 +40,11 @@ class Program(object):
         """
         # Arguments present always, even when wrapped as a different binary
         return [
+            Argument(
+                names=("command-timeout", "T"),
+                kind=int,
+                help="Specify a global command execution timeout, in seconds.",
+            ),
             Argument(
                 names=("complete",),
                 kind=bool,
@@ -46,10 +52,8 @@ class Program(object):
                 help="Print tab-completion candidates for given parse remainder.",  # noqa
             ),
             Argument(
-                names=("print-completion-script",),
-                kind=str,
-                default="",
-                help="Print the tab-completion script for your preferred shell (bash|zsh|fish).",  # noqa
+                names=("config", "f"),
+                help="Runtime configuration file to use.",
             ),
             Argument(
                 names=("debug", "d"),
@@ -58,16 +62,10 @@ class Program(object):
                 help="Enable debug output.",
             ),
             Argument(
-                names=("prompt-for-sudo-password",),
+                names=("dry", "R"),
                 kind=bool,
                 default=False,
-                help="Prompt user at start of session for the sudo.password config value.",  # noqa
-            ),
-            Argument(
-                names=("write-pyc",),
-                kind=bool,
-                default=False,
-                help="Enable creation of .pyc files.",
+                help="Echo commands instead of running.",
             ),
             Argument(
                 names=("echo", "e"),
@@ -75,10 +73,6 @@ class Program(object):
                 default=False,
                 help="Echo executed commands before running.",
             ),
-            Argument(
-                names=("config", "f"),
-                help="Runtime configuration file to use.",
-            ),
             Argument(
                 names=("help", "h"),
                 optional=True,
@@ -104,6 +98,18 @@ class Program(object):
                 help="Change the display format used when listing tasks. Should be one of: flat (default), nested, json.",  # noqa
                 default="flat",
             ),
+            Argument(
+                names=("print-completion-script",),
+                kind=str,
+                default="",
+                help="Print the tab-completion script for your preferred shell (bash|zsh|fish).",  # noqa
+            ),
+            Argument(
+                names=("prompt-for-sudo-password",),
+                kind=bool,
+                default=False,
+                help="Prompt user at start of session for the sudo.password config value.",  # noqa
+            ),
             Argument(
                 names=("pty", "p"),
                 kind=bool,
@@ -122,6 +128,12 @@ class Program(object):
                 default=False,
                 help="Warn, instead of failing, when shell commands fail.",
             ),
+            Argument(
+                names=("write-pyc",),
+                kind=bool,
+                default=False,
+                help="Enable creation of .pyc files.",
+            ),
         ]
 
     def task_args(self):
@@ -233,7 +245,10 @@ class Program(object):
         :param executor_class:
             The `.Executor` subclass to use when executing tasks.
 
-            Defaults to `.Executor`.
+            Defaults to `.Executor`; may also be overridden at runtime by the
+            :ref:`configuration system <default-values>` and its
+            ``tasks.executor_class`` setting (anytime that setting is not
+            ``None``).
 
         :param config_class:
             The `.Config` subclass to use for the base config object.
@@ -298,16 +313,22 @@ class Program(object):
             run["hide"] = self.args.hide.value
         if self.args.echo.value:
             run["echo"] = True
+        if self.args.dry.value:
+            run["dry"] = True
         tasks = {}
         if "no-dedupe" in self.args and self.args["no-dedupe"].value:
             tasks["dedupe"] = False
+        timeouts = {}
+        command = self.args["command-timeout"].value
+        if command:
+            timeouts["command"] = command
         # Handle "fill in config values at start of runtime", which for now is
         # just sudo password
         sudo = {}
         if self.args["prompt-for-sudo-password"].value:
             prompt = "Desired 'sudo.password' config value: "
             sudo["password"] = getpass.getpass(prompt)
-        overrides = dict(run=run, tasks=tasks, sudo=sudo)
+        overrides = dict(run=run, tasks=tasks, sudo=sudo, timeouts=timeouts)
         self.config.load_overrides(overrides, merge=False)
         runtime_path = self.args.config.value
         if runtime_path is None:
@@ -458,7 +479,7 @@ class Program(object):
 
         .. versionadded:: 1.0
         """
-        halp = self.args.help.value or self.core_via_tasks.args.help.value
+        halp = self.args.help.value
 
         # Core (no value given) --help output (only when bundled namespace)
         if halp is True:
@@ -524,11 +545,24 @@ class Program(object):
 
         .. note::
             Client code just wanting a different `.Executor` subclass can just
-            set ``executor_class`` in `.__init__`.
+            set ``executor_class`` in `.__init__`, or override
+            ``tasks.executor_class`` anywhere in the :ref:`config system
+            <default-values>` (which may allow you to avoid using a custom
+            Program entirely).
 
         .. versionadded:: 1.0
         """
-        executor = self.executor_class(self.collection, self.config, self.core)
+        klass = self.executor_class
+        config_path = self.config.tasks.executor_class
+        if config_path is not None:
+            # TODO: why the heck is this not builtin to importlib?
+            module_path, _, class_name = config_path.rpartition(".")
+            # TODO: worth trying to wrap both of these and raising ImportError
+            # for cases where module exists but class name does not? More
+            # "normal" but also its own possible source of bugs/confusion...
+            module = import_module(module_path)
+            klass = getattr(module, class_name)
+        executor = klass(self.collection, self.config, self.core)
         executor.execute(*self.tasks)
 
     def normalize_argv(self, argv):
@@ -593,6 +627,7 @@ class Program(object):
         """
         return self._binary_names or [self.called_as]
 
+    # TODO 2.0: ugh rename this or core_args, they are too confusing
     @property
     def args(self):
         """
@@ -673,6 +708,15 @@ class Program(object):
         except CollectionNotFound as e:
             raise Exit("Can't find any collection named {!r}!".format(e.name))
 
+    def _update_core_context(self, context, new_args):
+        # Update core context w/ core_via_task args, if and only if the
+        # via-task version of the arg was truly given a value.
+        # TODO: push this into an Argument-aware Lexicon subclass and
+        # .update()?
+        for key, arg in new_args.items():
+            if arg.got_value:
+                context.args[key]._value = arg._value
+
     def parse_tasks(self):
         """
         Parse leftover args, which are typically tasks & per-task args.
@@ -681,6 +725,10 @@ class Program(object):
         parsed per-task contexts, and ``self.core_via_tasks`` to a context
         holding any core flags seen within the task contexts.
 
+        Also modifies ``self.core`` to include the data from ``core_via_tasks``
+        (so that it correctly reflects any supplied core flags regardless of
+        where they appeared).
+
         .. versionadded:: 1.0
         """
         self.parser = Parser(
@@ -689,8 +737,10 @@ class Program(object):
         )
         debug("Parsing tasks against {!r}".format(self.collection))
         result = self.parser.parse_argv(self.core.unparsed)
-        # TODO: can we easily 'merge' this into self.core? Ehh
         self.core_via_tasks = result.pop(0)
+        self._update_core_context(
+            context=self.core[0], new_args=self.core_via_tasks.args
+        )
         self.tasks = result
         debug("Resulting task contexts: {!r}".format(self.tasks))
 
